# Django Paddle Billing

[![PyPI - Version](https://img.shields.io/pypi/v/dj-paddle-billing.svg)](https://pypi.org/project/dj-paddle-billing)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dj-paddle-billing.svg)](https://pypi.org/project/dj-paddle-billing)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install dj-paddle-billing
```

## License

`dj-paddle-billing` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
